@@ -12,8 +12,9 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-
+import dataclasses
 from collections import OrderedDict
+from typing import List
 
 from cord.orm import base_orm
 
@@ -49,6 +50,18 @@ class Dataset(base_orm.BaseORM):
     }
 
 
+class DatasetData(base_orm.BaseORM):
+    """
+    Video base ORM.
+    """
+
+    DB_FIELDS = OrderedDict([
+        ("data_hash", str),
+        ("video", dict),
+        ("images", list),
+    ])
+
+
 class SignedVideoURL(base_orm.BaseORM):
     """ A signed URL object with supporting information. """
     DB_FIELDS = OrderedDict([
@@ -111,3 +124,17 @@ class Image(base_orm.BaseORM):
     NON_UPDATABLE_FIELDS = {
         "data_hash",
     }
+
+
+@dataclasses.dataclass(frozen=True)
+class ReEncodeVideoTaskResult:
+    data_hash: str
+    signed_url: str
+    bucket_path: str
+
+
+@dataclasses.dataclass(frozen=True)
+class ReEncodeVideoTask:
+    """ A re encode video object with supporting information. """
+    status: str
+    result: List[ReEncodeVideoTaskResult] = None
